@@ -23,8 +23,8 @@
 #define JIT_HASH_CONSTS		1
 #define JIT_NUM_OPERANDS	3
 
-#if defined(_ABIN32)
-#  define NEW_ABI		1
+#if _MIPS_SIM != _ABIO32
+#    define NEW_ABI		1
 #endif
 
 /*
