@@ -139,6 +139,7 @@ static void
 _rx(jit_state_t*,jit_int32_t,jit_int32_t,jit_int32_t,jit_int32_t,jit_int32_t);
 #  define nop(n)			_nop(_jit, n)
 static void _nop(jit_state_t*, jit_int32_t);
+#  define emms()			is(0x770f)
 #  define lea(md, rb, ri, ms, rd)	_lea(_jit, md, rb, ri, ms, rd)
 static void
 _lea(jit_state_t*,jit_int32_t,jit_int32_t,jit_int32_t,jit_int32_t,jit_int32_t);
@@ -3258,6 +3259,9 @@ _bxsubi_u(jit_state_t *_jit, jit_word_t i0, jit_int32_t r0, jit_word_t i1)
 static void
 _callr(jit_state_t *_jit, jit_int32_t r0)
 {
+#if __WORDSIZE == 32
+    emms();
+#endif
     rex(0, 0, _NOREG, _NOREG, r0);
     ic(0xff);
     mrm(0x03, 0x02, r7(r0));
@@ -3276,6 +3280,7 @@ _calli(jit_state_t *_jit, jit_word_t i0)
     jit_unget_reg(reg);
 #else
     jit_word_t		w;
+    emms();
     ic(0xe8);
     w = i0 - (_jit->pc.w + 4);
     ii(w);
