@@ -18,11 +18,6 @@
  */
 
 #if PROTO
-#  if __WORDSIZE == 32
-#    define CVT_OFFSET			-12
-#  else
-#    define CVT_OFFSET			-8
-#  endif
 #  define _ST0_REGNO			0
 #  define _ST1_REGNO			1
 #  define _ST2_REGNO			2
@@ -56,7 +51,7 @@ _x87rx(jit_state_t*, jit_int32_t, jit_int32_t,
 #  define fldl2e()			x87ri(015, 2)
 #  define fldpi()			x87ri(015, 3)
 #  define fldlg2()			x87ri(015, 4)
-#  define fldln2()			x87ri(015, 4)
+#  define fldln2()			x87ri(015, 5)
 #  define fldz()			x87ri(015, 6)
 #  define fsqrt_()			x87ri(017, 2)
 #  define fldr(r0)			x87ri(010, r0)
@@ -937,7 +932,7 @@ _x87_stxi_f(jit_state_t *_jit, jit_word_t i0, jit_int32_t r0, jit_int32_t r1)
 	x87_stxr_f(rn(reg), r0, r1);
 	jit_unget_reg(reg);
     }
-    else if (r0 == _ST0_REGNO)
+    else if (r1 == _ST0_REGNO)
 	fstsm(i0, r0, _NOREG, _SCL1);
     else {
 	fxchr(r1);
@@ -1097,7 +1092,7 @@ _x87_ldi_d(jit_state_t *_jit, jit_int32_t r0, jit_word_t i0)
     else {
 	reg = jit_get_reg(jit_class_gpr);
 	movi(rn(reg), i0);
-	x87_ldr_f(r0, rn(reg));
+	x87_ldr_d(r0, rn(reg));
 	jit_unget_reg(reg);
     }
 }
